@@ -281,7 +281,7 @@ int register_conf_table(const char *name, struct ci_conf_entry *table, int type)
         conf_tables_num++;
     }
 
-    ci_debug_printf(10, "Registering conf table:%s\n", name);
+    ci_debug_printf(10, "Registering conf table: %s\n", name);
 
     extra_conf_tables[insert_pos].name = name;    /*It works. Points to the modules.name. (????) */
     extra_conf_tables[insert_pos].type = type;
@@ -391,7 +391,7 @@ int print_variables()
 int cfg_set_port(const char *directive, const char **argv, void *setdata)
 {
     int i;
-    char *s;
+    char *s, *addr, *connect_port;
     ci_port_t *pcfg = NULL;
     ci_port_t tmpP;
     ci_vector_t **port_configs = (ci_vector_t **)setdata;
@@ -410,14 +410,27 @@ int cfg_set_port(const char *directive, const char **argv, void *setdata)
         return 0;
     }
 
-    if ((s = strchr(argv[0], ':'))) {
-        *s = '\0'; /*maybe use strdup/strndup?*/
-        pcfg->address = strdup(argv[0]);
+    connect_port = strdup(argv[0]);
+    if ((s = strrchr(connect_port, ':'))) {
+        *s = '\0';
+        addr = connect_port;
+        if (*addr == '[') {
+            if (addr[strlen(addr) - 1] != ']') {
+                ci_debug_printf(1, "Failed to parse listen address: %s\n", addr);
+                free(connect_port);
+                return 0;
+            }
+            ++addr;
+            addr[strlen(addr) - 1] = '\0';
+        }
+        pcfg->address = strdup(addr);
         s++;
     } else
-        s = (char *)argv[0];
+        s = connect_port;
 
     pcfg->port = atoi(s);
+    free(connect_port);
+    connect_port = s = NULL;
     if (pcfg->port <= 0) {
         ci_debug_printf(1, "Failed to parse %s (parsed port number:%d)\n", directive, pcfg->port);
         return 0;
@@ -477,7 +490,7 @@ int cfg_load_service(const char *directive, const char **argv, void *setdata)
         ci_debug_printf(1, "Missing arguments in LoadService directive\n");
         return 0;
     }
-    ci_debug_printf(2, "Loading service :%s path %s\n", argv[0], argv[1]);
+    ci_debug_printf(2, "Loading service: %s path %s\n", argv[0], argv[1]);
 
     if (!(service = register_service(argv[1], argv + 2))) {
         ci_debug_printf(1, "Error loading service %s\n", argv[1]);
@@ -499,7 +512,7 @@ int cfg_service_alias(const char *directive, const char **argv, void *setdata)
         service_args++;
     }
 
-    ci_debug_printf(2, "Alias:%s of service %s\n", argv[0], argv[1]);
+    ci_debug_printf(2, "Alias: %s of service %s\n", argv[0], argv[1]);
     add_service_alias(argv[0], argv[1], service_args);
     return 1;
 }
@@ -510,7 +523,7 @@ int cfg_load_module(const char *directive, const char **argv, void *setdata)
         ci_debug_printf(1, "Missing arguments in LoadModule directive\n");
         return 0;
     }
-    ci_debug_printf(2, "Loading service :%s path %s\n", argv[0], argv[1]);
+    ci_debug_printf(2, "Loading service: %s path %s\n", argv[0], argv[1]);
 
     if (!register_module(argv[1], argv[0], argv + 2)) {
         ci_debug_printf(1, "Error loading module %s, module path %s\n", argv[1], argv[0]);
@@ -583,7 +596,7 @@ int cfg_set_logger(const char *directive, const char **argv, void *setdata)
     if (!(logger = find_logger(argv[0])))
         return 0;
     default_logger = logger;
-    ci_debug_printf(2, "Setting parameter :%s=%s\n", directive, argv[0]);
+    ci_debug_printf(2, "Setting parameter: %s=%s\n", directive, argv[0]);
     return 1;
 }
 
@@ -612,7 +625,7 @@ int cfg_set_tmp_dir(const char *directive, const char **argv, void *setdata)
 #endif
     /*Check if tmpdir exists. If no try to build it , report an error and uses the default... */
     CI_TMPDIR = CI_CONF.TMPDIR;   /*Sets the library's temporary dir to .... */
-    ci_debug_printf(2, "Setting parameter :%s=%s\n", directive, argv[0]);
+    ci_debug_printf(2, "Setting parameter: %s=%s\n", directive, argv[0]);
     return 1;
 }
 
