@@ -299,7 +299,7 @@ static void wait_childs_to_exit(struct childs_queue *q)
     for (i = 0; i < q->size; i++) {
         if (q->childs[i].pid == 0)
             continue;
-        ci_debug_printf(5, "Wait for child with pid:%d\n", q->childs[i].pid);
+        ci_debug_printf(5, "Wait for child with pid: %d\n", q->childs[i].pid);
         if (q->childs[i].to_be_killed != IMMEDIATELY) {
             ci_debug_printf(5, "Child %d not signaled yet!\n", q->childs[i].pid);
             continue;
@@ -322,7 +322,6 @@ static void kill_all_childs()
     int childs_running;
     ci_debug_printf(5, "Going to term children....\n");
 
-    childs_running = 0;
     do {
         send_term_to_childs(childs_queue);
         if (old_childs_queue)
@@ -357,7 +356,7 @@ static void check_for_exited_childs()
             ci_debug_printf(1, "Child %d did not exit normally.", pid);
             exit_status = 1;
             if (WIFSIGNALED(status))
-                ci_debug_printf(1, "signaled with signal:%d\n",
+                ci_debug_printf(1, "signaled with signal: %d\n",
                                 WTERMSIG(status));
         }
         ret = remove_child(childs_queue, pid, exit_status);
@@ -368,7 +367,9 @@ static void check_for_exited_childs()
             remove_child(old_childs_queue, pid, exit_status);
             if (childs_queue_is_empty(old_childs_queue)) {
                 ret = destroy_childs_queue(old_childs_queue);
-                /* if(!ret){} */
+                if (!ret) {
+                    ci_debug_printf(1, "WARNING: can not release unused shared mem block after reconfigure\n");
+                }
                 old_childs_queue = NULL;
             }
         }
@@ -583,7 +584,8 @@ int thread_main(server_decl_t * srv)
                 return 1;
             }
             ret = wait_for_queue(con_queue);
-            continue;
+            if (ret >= 0)
+                continue;
         }
 
         if (ret < 0) {        //An error has occured
@@ -701,7 +703,7 @@ void listener_thread(void *unused)
     pid = getpid();
     for (;;) {                 //Global for
         if (child_data->to_be_killed) {
-            ci_debug_printf(5, "Listener of pid:%d exiting!\n", pid);
+            ci_debug_printf(5, "Listener of pid: %d exiting!\n", pid);
             goto LISTENER_FAILS_UNLOCKED;
         }
         if (!ci_proc_mutex_lock(&accept_mutex)) {
@@ -894,13 +896,15 @@ void child_main(int pipefd)
         ret =
             ci_thread_create(&thread, (void *(*)(void *)) thread_main,
                              (void *) threads_list[i]);
-        threads_list[i]->srv_pthread = thread;
+        if (ret == 0)
+            threads_list[i]->srv_pthread = thread;
     }
     threads_list[CI_CONF.THREADS_PER_CHILD] = NULL;
     /*Now start the listener thread.... */
     ret = ci_thread_create(&thread, (void *(*)(void *)) listener_thread,
                            NULL);
-    listener_thread_id = thread;
+    if (ret == 0)
+        listener_thread_id = thread;
 
     /*set srand for child......*/
     srand(((unsigned int)time(NULL)) + (unsigned int)getpid());
@@ -1198,7 +1202,7 @@ int start_server()
                     ci_debug_printf(1,
                                     "ATTENTION!!!! Not enough available servers (children %d, free servers %d, used servers %d)!!!!! "
                                     "Maybe you should increase the MaxServers and the "
-                                    "ThreadsPerChild values in c-icap.conf file!!!!!!!!!",childs , freeservers, used);
+                                    "ThreadsPerChild values in c-icap.conf file!!!!!!!!!", childs, freeservers, used);
                     user_informed = 1;
                 }
             }
