@@ -378,7 +378,8 @@ static int parse_request(ci_request_t * req, char *buf)
                        len : (MAX_SERVICE_ARGS - args_len));
                 strncpy(req->args + args_len, start, len);
                 req->args[args_len + len] = '\0';
-            }
+            } else
+                return EC_400;
         }      /*end of parsing args */
     }
 
@@ -459,6 +460,8 @@ static int check_request(ci_request_t *req)
         if (req->entities[3] != NULL)
             return EC_400;
         else if (req->entities[2] != NULL) {
+            assert(req->entities[0]);
+            assert(req->entities[1]);
             if (req->entities[0]->type != ICAP_REQ_HDR)
                 return EC_400;
             if (req->entities[1]->type != ICAP_RES_HDR)
@@ -796,7 +799,7 @@ static int format_body_chunk(ci_request_t * req)
         req->remain_send_block_bytes += def_bytes + 2;
     } else if (req->remain_send_block_bytes == CI_EOF) {
         if (req->return_code == EC_206 && req->i206_use_original_body >= 0) {
-            def_bytes = sprintf(req->wbuf, "0; use-original-body=%ld\r\n\r\n",
+            def_bytes = sprintf(req->wbuf, "0; use-original-body=%" PRId64 "\r\n\r\n",
                                 req->i206_use_original_body );
             req->pstrblock_responce = req->wbuf;
             req->remain_send_block_bytes = def_bytes;
@@ -950,7 +953,6 @@ static int get_send_body(ci_request_t * req, int parse_only)
     if (req->pstrblock_read_len == 0)
         action = ci_wait_for_read;
     do {
-        ret = 0;
         if (action) {
             ci_debug_printf(9, "Going to %s/%s data\n",
                             (action & ci_wait_for_read ? "Read" : "-"),
@@ -1029,7 +1031,6 @@ static int get_send_body(ci_request_t * req, int parse_only)
             } else
                 rbytes = 0;
 
-            no_io = 0;
             ci_debug_printf(9, "get send body: going to write/read: %d/%d bytes\n", wbytes, rbytes);
             if ((*service_io)
                     (rchunkdata, &rbytes, wchunkdata, &wbytes, req->eof_received,
@@ -1075,7 +1076,20 @@ static int get_send_body(ci_request_t * req, int parse_only)
 
     if (!action) {
         ci_debug_printf(1,
-                        "Bug in the service. Please report to the service author!!!!\n");
+                        "Bug in the service '%s'. "
+                        "Please report to the service author!!!!\n"
+                        "request status: %d\n"
+                        "request data locked?: %d\n"
+                        "Write to module pending: %d\n"
+                        "Remain send block bytes: %d\n"
+                        "Read block len: %d\n",
+                        req->service,
+                        req->status,
+                        req->data_locked,
+                        req->write_to_module_pending,
+                        req->remain_send_block_bytes,
+                        req->pstrblock_read_len
+            );
     } else {
         ci_debug_printf(5, "Error reading from network......\n");
     }
@@ -1203,14 +1217,14 @@ static void options_responce(ci_request_t * req)
     ttl = srv_xdata->options_ttl;
     ci_service_data_read_unlock(srv_xdata);
 
-    ci_debug_printf(5, "Options responce:\n"
-                    " Preview :%d\n"
-                    " Allow 204:%s\n"
-                    " Allow 206:%s\n"
-                    " TransferPreview:\"%s\"\n"
-                    " TransferIgnore:%s\n"
-                    " TransferComplete:%s\n"
-                    " Max-Connections:%d\n",
+    ci_debug_printf(5, "Options response: \n"
+                    " Preview: %d\n"
+                    " Allow 204: %s\n"
+                    " Allow 206: %s\n"
+                    " TransferPreview: \"%s\"\n"
+                    " TransferIgnore: %s\n"
+                    " TransferComplete: %s\n"
+                    " Max-Connections: %d\n",
                     preview,(allow204?"yes":"no"),
                     (allow206?"yes":"no"),
                     srv_xdata->TransferPreview,
@@ -1514,7 +1528,7 @@ static int do_end_of_data(ci_request_t * req)
 static int do_request(ci_request_t * req)
 {
     ci_service_xdata_t *srv_xdata = NULL;
-    int res, preview_status = 0, auth_status = CI_ACCESS_ALLOW;
+    int res, preview_status = 0, auth_status;
     int ret_status = CI_OK; /*By default ret_status is CI_OK, on error must set to CI_ERROR*/
     res = parse_header(req);
     if (res != EC_100) {
@@ -1525,7 +1539,7 @@ static int do_request(ci_request_t * req)
         if (res > EC_100 && req->request_header->bufused > 0)
             ec_responce(req, res);
         ci_debug_printf((req->request_header->bufused ? 5 : 11), "Error %d while parsing headers :(%d)\n",
-                        res ,req->request_header->bufused);
+                        res, req->request_header->bufused);
         return CI_ERROR;
     }
     assert(req->current_service_mod);
@@ -1537,7 +1551,6 @@ static int do_request(ci_request_t * req)
         return CI_ERROR;
     }
 
-    auth_status = req->access_type;
     if ((auth_status = access_check_request(req)) == CI_ACCESS_DENY) {
         req->keepalive = 0;
         if (req->auth_required) {
@@ -1545,6 +1558,7 @@ static int do_request(ci_request_t * req)
         } else {
             ec_responce(req, EC_403); /*Forbitten*/
         }
+        ci_debug_printf(3, "Request not authenticated, status: %d\n", auth_status);
         return CI_ERROR;      /*Or something that means authentication error */
     }
 
@@ -1573,7 +1587,6 @@ static int do_request(ci_request_t * req)
         break;
     case ICAP_REQMOD:
     case ICAP_RESPMOD:
-        preview_status = CI_NO_STATUS;
         if (req->preview >= 0) /*we are inside preview*/
             preview_status = do_request_preview(req);
         else {
